@@ -26,51 +26,51 @@ SSTable = function(b, a, first, last,setA, setB, cIM_score=NULL)
 
 
 ### Greatest Common Divisor via Euclid's algorithm
-GCD2_ =function (n, m) 
-{
-  if (n == 0 && m == 0) 
-    return(0)
-  n = abs(n)
-  m = abs(m)
-  if (m > n) {
-    t = n
-    n = m
-    m = t
-  }
-  while (m > 0) {
-    t = n
-    n = m
-    m = t%%m
-  }
-  return(n)
-}
-
-
-GCD_ =function (x) 
-{
-  if (floor(x) != ceiling(x) || length(x) < 2) 
-    stop("Argument 'x' must be an integer vector of length >= 2.")
-  x = x[x != 0]
-  n = length(x)
-  if (n == 0) {
-    g = 0
-  }
-  else if (n == 1) {
-    g = x
-  }
-  else if (n == 2) {
-    g = GCD2_(x[1], x[2])
-  }
-  else {
-    g = GCD2_(x[1], x[2])
-    for (i in 3:n) {
-      g = GCD2_(g, x[i])
-      if (g == 1) 
-        break
-    }
-  }
-  return(g)
-}
+# GCD2_ =function (n, m) 
+# {
+#   if (n == 0 && m == 0) 
+#     return(0)
+#   n = abs(n)
+#   m = abs(m)
+#   if (m > n) {
+#     t = n
+#     n = m
+#     m = t
+#   }
+#   while (m > 0) {
+#     t = n
+#     n = m
+#     m = t%%m
+#   }
+#   return(n)
+# }
+# 
+# 
+# GCD_ =function (x) 
+# {
+#   if (floor(x) != ceiling(x) || length(x) < 2) 
+#     stop("Argument 'x' must be an integer vector of length >= 2.")
+#   x = x[x != 0]
+#   n = length(x)
+#   if (n == 0) {
+#     g = 0
+#   }
+#   else if (n == 1) {
+#     g = x
+#   }
+#   else if (n == 2) {
+#     g = GCD2_(x[1], x[2])
+#   }
+#   else {
+#     g = GCD2_(x[1], x[2])
+#     for (i in 3:n) {
+#       g = GCD2_(g, x[i])
+#       if (g == 1) 
+#         break
+#     }
+#   }
+#   return(g)
+# }
 
 # highest posterior density interval
 # not safe for bimodal distributions
@@ -98,61 +98,61 @@ hpdens = function(x, conf=0.95)
 # item parameters from posterior.
 
 #TO~DO: protect against NA's
-conf_env = function(mat, level = 0.95) 
-{
-  overall_found = TRUE
-  emperr = function(rmat, p = 0.05, k = NULL) {
-    R = nrow(rmat)
-    if (is.null(k)) 
-      k = p * (R + 1)/2
-    else p = 2 * k/(R + 1)
-    kf = function(x, k, R) 1 * ((min(x) <= k) | (max(x) >= 
-                                                    R + 1L - k))
-    c(k, p, sum(apply(rmat, 1L, kf, k, R))/(R + 1))
-  }
-  kfun = function(x, k1, k2) sort(x, partial = sort(c(k1, k2)))[c(k1, k2)]
-  index = 1L:ncol(mat)
-  if (length(index) < 2L) 
-    stop("This function for curves")
-  rmat = apply(mat, 2L, rank)
-  R = nrow(mat)
-  if (length(level) == 1L) 
-    level = rep(level, 2L)
-  k.pt = floor((R + 1) * (1 - level[1L])/2 + 1e-10)
-  k.pt = c(k.pt, R + 1 - k.pt)
-  err.pt = emperr(rmat, k = k.pt[1L])
-  ov = emperr(rmat, k = 1)
-  ee = err.pt
-  al = 1 - level[2L]
-  if (ov[3L] > al) 
-    overall_found = FALSE
-  else {
-    continue = !(ee[3L] < al)
-    while (continue) {
-      kk = ov[1L] + round((ee[1L] - ov[1L]) * (al - ov[3L])/(ee[3L] - 
-                                                                ov[3L]))
-      if (kk == ov[1L]) 
-        kk = kk + 1
-      else if (kk == ee[1L]) 
-        kk = kk - 1
-      temp = emperr(rmat, k = kk)
-      if (temp[3L] > al) 
-        ee = temp
-      else ov = temp
-      continue = !(ee[1L] == ov[1L] + 1)
-    }
-  }
-  k.ov = c(ov[1L], R + 1 - ov[1L])
-  err.ov = ov[-1L]
-  out = apply(mat, 2L, kfun, k.pt, k.ov)
-  if (overall_found){
-    out = out[4:3, ]
-  }else
-  {
-    out = out[1:2, ]
-  }
-  return(out)
-}
+# conf_env = function(mat, level = 0.95) 
+# {
+#   overall_found = TRUE
+#   emperr = function(rmat, p = 0.05, k = NULL) {
+#     R = nrow(rmat)
+#     if (is.null(k)) 
+#       k = p * (R + 1)/2
+#     else p = 2 * k/(R + 1)
+#     kf = function(x, k, R) 1 * ((min(x) <= k) | (max(x) >= 
+#                                                     R + 1L - k))
+#     c(k, p, sum(apply(rmat, 1L, kf, k, R))/(R + 1))
+#   }
+#   kfun = function(x, k1, k2) sort(x, partial = sort(c(k1, k2)))[c(k1, k2)]
+#   index = 1L:ncol(mat)
+#   if (length(index) < 2L) 
+#     stop("This function for curves")
+#   rmat = apply(mat, 2L, rank)
+#   R = nrow(mat)
+#   if (length(level) == 1L) 
+#     level = rep(level, 2L)
+#   k.pt = floor((R + 1) * (1 - level[1L])/2 + 1e-10)
+#   k.pt = c(k.pt, R + 1 - k.pt)
+#   err.pt = emperr(rmat, k = k.pt[1L])
+#   ov = emperr(rmat, k = 1)
+#   ee = err.pt
+#   al = 1 - level[2L]
+#   if (ov[3L] > al) 
+#     overall_found = FALSE
+#   else {
+#     continue = !(ee[3L] < al)
+#     while (continue) {
+#       kk = ov[1L] + round((ee[1L] - ov[1L]) * (al - ov[3L])/(ee[3L] - 
+#                                                                 ov[3L]))
+#       if (kk == ov[1L]) 
+#         kk = kk + 1
+#       else if (kk == ee[1L]) 
+#         kk = kk - 1
+#       temp = emperr(rmat, k = kk)
+#       if (temp[3L] > al) 
+#         ee = temp
+#       else ov = temp
+#       continue = !(ee[1L] == ov[1L] + 1)
+#     }
+#   }
+#   k.ov = c(ov[1L], R + 1 - ov[1L])
+#   err.ov = ov[-1L]
+#   out = apply(mat, 2L, kfun, k.pt, k.ov)
+#   if (overall_found){
+#     out = out[4:3, ]
+#   }else
+#   {
+#     out = out[1:2, ]
+#   }
+#   return(out)
+# }
 
 
 # equivalent to log(sum(exp(x)))
@@ -174,31 +174,31 @@ logsumexp = function(x)
 # usethis::use_data(quadpoints, internal = TRUE)
 
 
-geo_mean = function(x)
-{
-  return(exp(mean(log(x))))
-}
+# geo_mean = function(x)
+# {
+#   return(exp(mean(log(x))))
+# }
 ### round to geometric mean ###
 # Round positive numbers x to integers
 # such that the geometric mean equals approximately J
-r2gm = function(x, J)
-{
-  G=geo_mean(x)
-  out=NULL
-  for (i in 1:length(x)) out = c(out,max(1,floor(0.5+(J*x[i]/G))))
-  return(out)
-}
+# r2gm = function(x, J)
+# {
+#   G=geo_mean(x)
+#   out=NULL
+#   for (i in 1:length(x)) out = c(out,max(1,floor(0.5+(J*x[i]/G))))
+#   return(out)
+# }
 
 ### Weights based on a rank-one approximation to the
 # Interaction model
-c2weights = function(cIM)
-{
-  hh=kronecker(t(cIM),cIM,'+')
-  gg=eigen(hh)
-  out=abs(gg$vectors[,which.max(gg$values)])
-  av_indx=which.min(abs(out-mean(out)))
-  return(out/out[av_indx])
-}
+# c2weights = function(cIM)
+# {
+#   hh=kronecker(t(cIM),cIM,'+')
+#   gg=eigen(hh)
+#   out=abs(gg$vectors[,which.max(gg$values)])
+#   av_indx=which.min(abs(out-mean(out)))
+#   return(out/out[av_indx])
+# }
 
 
 all_trivial_scores = function(scores)
