@@ -6,7 +6,7 @@ RcppArmadillo::armadillo_throttle_cores(1)
 
 
 test_that('basic plausible scores checks',{
-  db = open_project(test_path('verbAggression.db'))
+  db = open_project(test_path('testdata/verbAggression.db'))
   f = fit_enorm(db)
 
   itm = get_items(db) |> filter(item_id!='S1DoCurse')
